function [  ] = SlopeField( T_min, T_max, T_step, Y_min, Y_max, Y_step )
%SlopeField::  This function creates a normalized slope field 
%   There is no output for this function. The input variables are as
%   follows:
%T_min      : The minimum t-value in our graph.
%T_max      : The maximum t-value in our graph.
%T_step     : The spacing in 't' between the slope lines.
%Y_min      : The minimum y-value in our graph.
%Y_max      : The maximum y-value in our graph.
%Y_step     : The spacing in 'y' between the slope lines.

% This function creates a matrix T and a matrix Y
%
[T,Y] = meshgrid(T_min:T_step:T_max,Y_min:Y_step:Y_max);

% We want to create a vector field, with vectors located at the points
% designated by the matricies T and Y. 
% To that end, we create two new matrices 'rise' and 'run' which are the
% same size as T. 
    % 'rise' will contain the y-component of each vector 
    % 'run' will contain the x-component of each vector
rise=T;
run =T;

% We create a loop which will iterate over the coordinates (i,j) inside our
% matrices 'rise' and 'run'
for i = 1:length(rise(:,1))
    for j = 1:length(rise(1,:))
        % First we calculate the un-normalized vector
        Delta_T = 1;
        Delta_Y = F( T(i,j), Y(i,j));
        
        % In order to normalize our slope field, we calculate the vector
        % norm of ( Delta_T , Delta_Y )
        Norm = sqrt( Delta_T^2 + Delta_Y^2 );

        % We store the normalized vector
        rise(i,j) = Delta_Y / Norm;
        run(i,j) = Delta_T / Norm;
    end
end

% Using the function 'quiver', we produce our slope field!
quiver(T,Y,run,rise)

% We add on the labels 'T' and 'Y' onto the x and y axes respectively 
xlabel('T')
ylabel('Y')
end
